@@ -1,6 +1,6 @@
 """jc - JSON Convert `uname -a` command output parser
 
-Note: Must use `uname -a`
+> Note: Must use `uname -a`
 
 Usage (cli):
 
@@ -15,11 +15,6 @@ Usage (module):
     import jc
     result = jc.parse('uname', uname_command_output)
 
-    or
-
-    import jc.parsers.uname
-    result = jc.parsers.uname.parse(uname_command_output)
-
 Schema:
 
     {
